==> MiChip_1.0.0.zip: MiChip/doc/MiChip.R <==
###################################################
### chunk number 1: loadLibary
###################################################
library(MiChip)


###################################################
### chunk number 2: defaultRawData
###################################################
datadir <-system.file("extdata", package="MiChip")
defaultRawData <- parseRawData(datadir)


###################################################
### chunk number 3: noe
###################################################
 noEmptiesDataSet <- removeUnwantedRows(defaultRawData, c("Empty"))


###################################################
### chunk number 4: humanDataSet
###################################################
humanDataSet <- standardRemoveRows(defaultRawData)


###################################################
### chunk number 5: flagCorrectDataSet
###################################################
 flagCorrectedDataSet <- correctForFlags(humanDataSet)


###################################################
### chunk number 6: flagCorrectedDataSet
###################################################
flagCorrectedDataSet <- correctForFlags(humanDataSet, intensityCutoff = 50)


###################################################
### chunk number 7: summedData
###################################################
summedData <- summarizeIntensitiesAsMedian(flagCorrectedDataSet,minSumlength = 0, madAdjust=FALSE)


###################################################
### chunk number 8: plotIntensities
###################################################
plotIntensitiesScatter(exprs(summedData), NULL, "MiChipDemX", "SummarizedScatter")


###################################################
### chunk number 9: boxplotSummed
###################################################
 boxplotData(exprs(summedData), "MiChipDemX", "Summarized")


###################################################
### chunk number 10: mednormedData
###################################################
mednormedData <- normalizePerChipMedian(summedData)


###################################################
### chunk number 11: outputAnnot
###################################################
outputAnnotatedDataMatrix(mednormedData, "MiChipDemo", "medNormedIntensity",  "exprs")


###################################################
### chunk number 12: myNormedEset
###################################################
datadir <-system.file("extdata", package="MiChip")
 myNormedEset <- workedExampleMedianNormalize("NormedDemo", intensityCutoff = 50,datadir)

==> MiChip_1.4.0.zip: MiChip/doc/MiChip.R <==
###################################################
### chunk number 1: loadLibary
###################################################
#line 42 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
library(MiChip)


###################################################
### chunk number 2: defaultRawData
###################################################
#line 52 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
datadir <-system.file("extdata", package="MiChip")
defaultRawData <- parseRawData(datadir)


###################################################
### chunk number 3: noe
###################################################
#line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
 noEmptiesDataSet <- removeUnwantedRows(defaultRawData, c("Empty"))


###################################################
### chunk number 4: humanDataSet
###################################################
#line 83 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
humanDataSet <- standardRemoveRows(defaultRawData)


###################################################
### chunk number 5: flagCorrectDataSet
###################################################
#line 90 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
 flagCorrectedDataSet <- correctForFlags(humanDataSet)


###################################################
### chunk number 6: flagCorrectedDataSet
###################################################
#line 98 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
flagCorrectedDataSet <- correctForFlags(humanDataSet, intensityCutoff = 50)


###################################################
### chunk number 7: summedData
###################################################
#line 112 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
summedData <- summarizeIntensitiesAsMedian(flagCorrectedDataSet,minSumlength = 0, madAdjust=FALSE)


###################################################
### chunk number 8: plotIntensities
###################################################
#line 121 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
plotIntensitiesScatter(exprs(summedData), NULL, "MiChipDemX", "SummarizedScatter")


###################################################
### chunk number 9: boxplotSummed
###################################################
#line 136 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
 boxplotData(exprs(summedData), "MiChipDemX", "Summarized")


###################################################
### chunk number 10: mednormedData
###################################################
#line 155 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
mednormedData <- normalizePerChipMedian(summedData)


###################################################
### chunk number 11: outputAnnot
###################################################
#line 163 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
outputAnnotatedDataMatrix(mednormedData, "MiChipDemo", "medNormedIntensity",  "exprs")


###################################################
### chunk number 12: myNormedEset
###################################################
#line 170 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8undJf/R.INSTALL34c02b13/MiChip/inst/doc/MiChip.Rnw"
datadir <-system.file("extdata", package="MiChip")
 myNormedEset <- workedExampleMedianNormalize("NormedDemo", intensityCutoff = 50,datadir)
